@@ -12,7 +12,7 @@ class UTC(dt.tzinfo):
     def dst(self, dt):
         return ZERO
     def __repr__(self):
-        return "<UTC>"    
+        return "<UTC>"
 
 
 
@@ -28,3 +28,8 @@ def datetime(*args, **kwargs):
 def time(*args, **kwargs):
     kwargs['tzinfo'] = UTC()
     return dt.time(*args, **kwargs)
+
+
+def fromtimestamp(ts, **kwargs):
+    kwargs['tz'] = UTC()
+    return dt.datetime.fromtimestamp(ts, **kwargs)
